from enum import Enum


class GetAllPermissionsResponse200(str, Enum):
    ACCESS_MANAGEMENT = "ACCESS_MANAGEMENT"
    BOM_UPLOAD = "BOM_UPLOAD"
    POLICY_MANAGEMENT = "POLICY_MANAGEMENT"
    POLICY_VIOLATION_ANALYSIS = "POLICY_VIOLATION_ANALYSIS"
    PORTFOLIO_MANAGEMENT = "PORTFOLIO_MANAGEMENT"
    PROJECT_CREATION_UPLOAD = "PROJECT_CREATION_UPLOAD"
    SYSTEM_CONFIGURATION = "SYSTEM_CONFIGURATION"
    TAG_MANAGEMENT = "TAG_MANAGEMENT"
    VIEW_BADGES = "VIEW_BADGES"
    VIEW_POLICY_VIOLATION = "VIEW_POLICY_VIOLATION"
    VIEW_PORTFOLIO = "VIEW_PORTFOLIO"
    VIEW_VULNERABILITY = "VIEW_VULNERABILITY"
    VULNERABILITY_ANALYSIS = "VULNERABILITY_ANALYSIS"
    VULNERABILITY_MANAGEMENT = "VULNERABILITY_MANAGEMENT"

    def __str__(self) -> str:
        return str(self.value)
